@@ -6,9 +6,11 @@ import (
 
 // Args is a container for arguments that are passed from main() to fusefrontend
 type Args struct {
-	Masterkey      []byte
+	Masterkey []byte
+	// Cipherdir is the backing storage directory (absolute path).
+	// For reverse mode, Cipherdir actually contains *plaintext* files.
 	Cipherdir      string
-	CryptoBackend  cryptocore.BackendTypeEnum
+	CryptoBackend  cryptocore.AEADTypeEnum
 	PlaintextNames bool
 	LongNames      bool
 	// Should we chown a file after it has been created?
@@ -19,8 +21,16 @@ type Args struct {
 	// to "gocryptfs.conf" in the plaintext dir.
 	ConfigCustom bool
 	// Raw64 is true when RawURLEncoding (without padding) should be used for
-	// file names
+	// file names.
+	// Corresponds to the Raw64 feature flag introduced in gocryptfs v1.2.
 	Raw64 bool
 	// NoPrealloc disables automatic preallocation before writing
 	NoPrealloc bool
+	// Use HKDF key derivation.
+	// Corresponds to the HKDF feature flag introduced in gocryptfs v1.3.
+	HKDF bool
+	// Try to serialize read operations, "-serialize_reads"
+	SerializeReads bool
+	// Force decode even if integrity check fails (openSSL only)
+	ForceDecode bool
 }
